Changes committed gnus/lisp (ChangeLog gnus-art.el)

"Reiner Steib" <[email protected]> Mon, 16 Feb 2009 00:40:14 +0100
Newsgroups gmane.emacs.gnus.commits
Message-ID <[email protected]>
Modified: ChangeLog gnus-art.el

(gnus-button-alist): Recognize Konqueror info links.


Index: ChangeLog
diff -u gnus/lisp/ChangeLog:7.1985 gnus/lisp/ChangeLog:7.1986
--- ChangeLog:7.1985	Thu Feb  5 10:04:09 2009
+++ ChangeLog	Mon Feb 16 00:40:13 2009
@@ -1,3 +1,7 @@
+2009-02-15  Reiner Steib  <[email protected]>
+
+	* gnus-art.el (gnus-button-alist): Recognize Konqueror info links.
+
 2009-01-31  Glenn Morris  <[email protected]>
 
 	* gnus-sum.el (gnus-summary-next-article): XEmacs-friendly version of
@@ -26,10 +30,6 @@
 	* nntp.el (nntp-send-authinfo): Use list of
 	auth-source modes.
 
-2009-01-26  Teodor Zlatanov  <[email protected]>
-
-	* nntp.el (nntp-send-authinfo): 
-
 2009-01-16  Teodor Zlatanov  <[email protected]>
 
 	* auth-source.el: Update docs to reflect epa-file-enable is to be used
Index: gnus-art.el
diff -u gnus/lisp/gnus-art.el:7.288 gnus/lisp/gnus-art.el:7.289
--- gnus-art.el:7.288	Thu Jan 22 08:02:16 2009
+++ gnus-art.el	Mon Feb 16 00:40:13 2009
@@ -7408,7 +7408,11 @@
       gnus-button-ctan-directory-regexp
       "/[-_.a-z0-9]+/[-_./a-z0-9]+[/a-z0-9]\\)")
      1 (>= gnus-button-tex-level 8) gnus-button-handle-ctan 1)
-    ;; This is info (home-grown style) <info://foo/bar+baz>
+    ;; Info Konqueror style <info:/foo/bar baz>.
+    ;; Must come before " Gnus home-grown style".
+    ("\\binfo://?\\([^'\">\n\t]+\\)"
+     0 (>= gnus-button-emacs-level 1) gnus-button-handle-info-url 1)
+   ;; Info, Gnus home-grown style (deprecated) <info://foo/bar+baz>
     ("\\binfo://\\([^'\">\n\t ]+\\)"
      0 (>= gnus-button-emacs-level 1) gnus-button-handle-info-url 1)
     ;; Info GNOME style <info:foo#bar_baz>